#ifndef __basPlugin_h__
#define __basPlugin_h__

#include <Entry.h>
#include <Message.h>
#include <Bitmap.h>

/*
	Docs:
		The plugin runs on its own thread so if you
		wish to add an initial configuration window
		you should add something like 
			wait_for_thread(Window->Thread(), &status);
		after showing the window. The window should also
		be Modal so the user cant change the image with
		it being possible used by the plugin which would
		cause a segment violation.
*/

#define PLUGIN_TYPE_PROCESS_IMAGE	2
#define PLUGIN_TYPE_PROCESS_REFS	4

#define PLUGIN_CURRENT_API_VERSION	1

class basPlugin
{
public:
	basPlugin( unsigned int api_version )
	{
		APIVersion = api_version;
	}

	virtual int ProcessRefs( BMessage *msg ) = 0;
	/* msg is a BMessage with the "refs" field with
		the ImageList's entries */
	virtual int ProcessImage( BBitmap *in, BBitmap **out ) = 0;
	/* do whatever the plugin wants to <in>
		NOTE: you must alloc the <*out> bitmap */

	virtual void Configure() = 0;
	/* this isnt used for now */

	virtual const char *PluginName() = 0;
	/* should return a decent name to show up in the menu */
	virtual const int PluginVersion() = 0;
	/* should return the plugin's version */
	virtual const int PluginType() = 0;
	/* should return the type of the plugin (if you want your plugin
		to do both image and mass list processing just return
		PLUGIN_TYPE_PROCESS_IMAGE|PLUGIN_TYPE_PROCESS_REFS */

protected:
	unsigned int APIVersion;
};

/*
extern "C" basPlugin* ReturnPlugin(unsigned int params)
{
	return new basPlugin(params);
}
*/

#endif